@@ -1,5 +1,5 @@
 from .dtw import *
-from .dtwapprox import fastdtw, mrmsdtw
+from .dtwapprox import fastdtw, cdtw, mrmsdtw
 from .audiotools import *
 from .alignmenttools import get_csm, get_path_cost, get_alignment_row_col_dists, get_alignment_area_dist, refine_warping_path
 
